@@ -64,6 +64,11 @@ class level:
     def CreateSystem(system_name : str):
         save.SetStrArr(system_name, [''])
     
+    def CheckSystemExsists(system : str):
+        if path.exists(f'{system}_a.txt'):
+            return True
+        else: return False
+    
     def AddUser(system : str, user : str):
         sys = save.GetStrArr(system)
         if user in sys:
